@@ -22,7 +22,7 @@ import horizon
 class Monitoring(horizon.Dashboard):
     name = _("Monitoring")
     slug = "monitoring"
-    panels = ('overview', 'alarms', 'notifications')
+    panels = ('overview', 'alarmdefs', 'alarms', 'notifications',)
     default_panel = 'overview'
 
 
